Module pointer
Source - copy
- copies the memory contents of
src into a newly allocated pointer - create
- allocates a new, zero-initialized, raw pointer (i.e.:
*mut u8) of N contiguous bytes where N=length - destroy
- deallocates a raw pointer (i.e.:
*mut u8) of N contiguous bytes where N=length - from_display
- copies the memory from the underlying slice of bytes of the given
input into a newly allocated pointer. - from_slice
- copies the memory from the given slice of bytes into a newly allocated pointer
- get_byte_at_index
- retrieves a byte from contiguous memory area
- get_byte_slice_of
- retrieves a slice of N bytes from contiguous memory area where
N=count starting at index - get_valid_utf8_str_of
- retrieves
Some() valid str slice of N bytes from contiguous
memory area or None if the resulting sequence of bytes is not
valid UTF-8. - is_valid_utf8_str_of
- returns
true if the sequence of count bytes from index is a
valid UTF-8 sequence.